@@ -17,6 +17,8 @@
 render_funr <- function(x, max_rows = 100){
 
 	out = x$value
+	if(class(out)[1] == "try-error")
+		cat("")
 	vis = ifelse(length(x$visible) == 0, FALSE, x$visible)
 
 	#message("visible status: ", vis)
@@ -41,7 +43,7 @@ render_funr <- function(x, max_rows = 100){
 		print(out)
 
 	}else if(is.atomic(out)){
-		cat(out, "\n")
+		cat(out)
 
 	}else if(is.function(out)){
 		print(out)
